cis_config: CisObjOutput Class Reference

cis_config

Public Member Functions | List of all members
CisObjOutput Class Reference

C++ interface to cisObjOutput_t functionality. The CisObjOutput class is a basic wrapper around the C cisObjOutput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file output operations. More...

`#include <CisInterface.hpp>`

Inheritance diagram for CisObjOutput:

## Public Member Functions
| CisObjOutput (const char *name)
| Constructor for CisObjOutput. More...
| CisObjOutput (cisOutput_t x)
| Empty constructor for inheritance.
Public Member Functions inherited from CisOutput
| CisOutput (const char *name)
| Constructor for CisOutput. More...
| CisOutput (const char *name, const char *fmt)
| Constructor for CisOutput with format. More...
| CisOutput (cisOutput_t x)
| Empty constructor for inheritance.
void | _destroy_pi ()
| Alias to allow freeing of underlying C struct at the class level.
| ~CisOutput ()
| Destructor for CisOutput. See cis_free in CisInterface.h for details.
cisOutput_t | pi ()
| Return the cisOutput_t structure. More...
int | send (const char *data, const size_t len)
| Send a message smaller than CIS_MSG_MAX to the output queue. If the message is larger than CIS_MSG_MAX an error code will be returned. See cis_send in CisInterface.h for details. More...
int | send (const int nargs,...)
| Format and send a message smaller than CIS_MSG_MAX to the output queue. See cisSend from CisInterface.h for details. More...
int | send_nolimit (const char *data, const size_t len)
| Send a message larger than CIS_MSG_MAX to the output queue. See cis_send_nolimit in CisInterface.h for details. More...
int | send_nolimit (const int nargs,...)
| Format and send a message larger than CIS_MSG_MAX to the output queue. See cisSend from CisInterface.h for details. More...
int | send_eof ()
| Send EOF message to output file, closing it. More...

## Detailed Description

C++ interface to cisObjOutput_t functionality. The CisObjOutput class is a basic wrapper around the C cisObjOutput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file output operations.

## Constructor & Destructor Documentation

## ◆ CisObjOutput()

CisObjOutput::CisObjOutput | ( | const char * | name | ) |
| inline

Constructor for CisObjOutput.

Parameters

  [in] | name | constant character pointer to the name of an output channel.

The documentation for this class was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/interface/CisInterface.hpp